@@ -1,5 +1,5 @@
 use common::array::{sort_strings, transform};
-use common::pep508::{format_requirement, get_canonic_requirement_name};
+use common::pep508::Requirement;
 use common::table::{for_entries, reorder_table_keys, Tables};
 use lexical_sort::{lexical_cmp, natural_lexical_cmp};
 
@@ -11,10 +11,12 @@ pub fn fix(tables: &Tables, keep_full_version: bool) {
     let table = &mut table_element.unwrap().first().unwrap().borrow_mut();
     for_entries(table, &mut |key, entry| match key.as_str() {
         "requires" => {
-            transform(entry, &|s| format_requirement(s, keep_full_version));
+            transform(entry, &|s| {
+                Requirement::new(s).unwrap().normalize(keep_full_version).to_string()
+            });
             sort_strings::<String, _, _>(
                 entry,
-                |s| get_canonic_requirement_name(s.as_str()).to_lowercase(),
+                |s| Requirement::new(s.as_str()).unwrap().canonical_name(),
                 &|lhs, rhs| natural_lexical_cmp(lhs, rhs),
             );
         }
